# RFC 1924

This python library is an implementation of [RFC 1924](https://www.rfc-editor.org/rfc/rfc1924). 

## A Compact Representation of IPv6 Addresses

With this library you can store IPv6 addresses in a more compact form. It's Base85 encoded.